==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OrgBillingContactType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OrgBillingContactTypeLinks;
import com.okta.sdk.resource.model.OrgContactType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Org billing contact
 */
@ApiModel(description = "Org billing contact")
@JsonPropertyOrder({ OrgBillingContactType.JSON_PROPERTY_CONTACT_TYPE, OrgBillingContactType.JSON_PROPERTY_LINKS })
@JsonTypeName("orgBillingContactType")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OrgBillingContactType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTACT_TYPE = "contactType";
    private OrgContactType contactType;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private OrgBillingContactTypeLinks links;

    public OrgBillingContactType() {
    }

    public OrgBillingContactType contactType(OrgContactType contactType) {

        this.contactType = contactType;
        return this;
    }

    /**
     * Get contactType
     *
     * @return contactType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgContactType getContactType() {
        return contactType;
    }

    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContactType(OrgContactType contactType) {
        this.contactType = contactType;
    }

    public OrgBillingContactType links(OrgBillingContactTypeLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgBillingContactTypeLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(OrgBillingContactTypeLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OrgBillingContactType orgBillingContactType = (OrgBillingContactType) o;
        return Objects.equals(this.contactType, orgBillingContactType.contactType)
                && Objects.equals(this.links, orgBillingContactType.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(contactType, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OrgBillingContactType {\n");
        sb.append("    contactType: ").append(toIndentedString(contactType)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/OrgBillingContactType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OrgBillingContactTypeLinks;
import com.okta.sdk.resource.model.OrgContactType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Org billing contact
 */
@ApiModel(description = "Org billing contact")
@JsonPropertyOrder({ OrgBillingContactType.JSON_PROPERTY_CONTACT_TYPE, OrgBillingContactType.JSON_PROPERTY_LINKS })
@JsonTypeName("orgBillingContactType")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OrgBillingContactType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTACT_TYPE = "contactType";
    private OrgContactType contactType;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private OrgBillingContactTypeLinks links;

    public OrgBillingContactType() {
    }

    public OrgBillingContactType contactType(OrgContactType contactType) {

        this.contactType = contactType;
        return this;
    }

    /**
     * Get contactType
     *
     * @return contactType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgContactType getContactType() {
        return contactType;
    }

    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContactType(OrgContactType contactType) {
        this.contactType = contactType;
    }

    public OrgBillingContactType links(OrgBillingContactTypeLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgBillingContactTypeLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(OrgBillingContactTypeLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OrgBillingContactType orgBillingContactType = (OrgBillingContactType) o;
        return Objects.equals(this.contactType, orgBillingContactType.contactType)
                && Objects.equals(this.links, orgBillingContactType.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(contactType, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OrgBillingContactType {\n");
        sb.append("    contactType: ").append(toIndentedString(contactType)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
